@@ -1,7 +1,7 @@
 #
 #       images.R
 #
-#         $Revision: 1.75 $     $Date: 2010/10/21 03:26:05 $
+#         $Revision: 1.76 $     $Date: 2010/11/08 07:32:04 $
 #
 #      The class "im" of raster images
 #
@@ -452,6 +452,14 @@ as.matrix.im <- function(x, ...) {
   return(x$v)
 }
 
+as.array.im <- function(x, ...) {
+  m <- as.matrix(x)
+  a <- do.call(array, resolve.defaults(list(m),
+                                       list(...),
+                                       list(dim=c(dim(m), 1))))
+  return(a)
+}
+
 as.data.frame.im <- function(x, ...) {
   verifyclass(x, "im")
   v <- x$v
