@@ -4,7 +4,7 @@
 # computes residuals for fitted point process model
 #
 #
-# $Revision: 1.6 $ $Date: 2008/07/25 19:37:05 $
+# $Revision: 1.8 $ $Date: 2010/11/01 03:31:48 $
 #
 
 residuals.ppm <- function(object, type="raw", ..., check=TRUE, drop=FALSE,
@@ -15,16 +15,13 @@ residuals.ppm <- function(object, type="raw", ..., check=TRUE, drop=FALSE,
   if(check && missing(fittedvalues) && damaged.ppm(object)) 
     stop("object format corrupted; try update(object, use.internal=TRUE)")
 
-  typetable <- c("inverse", "raw", "pearson", "Pearson")
-  typemap <-   c("inverse", "raw", "pearson", "pearson")
+  type <- pickoption("type", type,
+                     c(inverse="inverse",
+                       raw="raw",
+                       pearson="pearson",
+                       Pearson="pearson",
+                       score="score"))
   
-  if(is.na(m <- pmatch(type, typetable)))
-    stop(paste("Unrecognised choice of",
-               paste(sQuote("type"), ":", sep=""),
-               type))
-  else
-    type <- typemap[m]
-
   # Extract quadrature points and weights
   Q <- quad.ppm(object, drop=drop)
   U <- union.quad(Q) # quadrature points
@@ -38,25 +35,37 @@ residuals.ppm <- function(object, type="raw", ..., check=TRUE, drop=FALSE,
   # (adjusted for numerical behaviour of predict.glm)
   indicator <- (lambda > .Machine$double.eps)
 
+  if(type == "score") {
+    # need the covariates
+    X <- model.matrix(object)
+    if(drop) {
+      gs <- getglmsubset(object)
+      ok <- !is.na(gs) && gs
+      X <- X[ok,]
+    }
+  }
+      
   # Evaluate residual measure components
-  discrete <- ifelse(Z,
-                     switch(type,
-                            raw     = 1,
-                            inverse = 1/lambda,
-                            pearson = 1/sqrt(lambda)
-                            ),
-                     0)
+  discrete <- switch(type,
+                     raw     = as.integer(Z),
+                     inverse = ifelse(Z, 1/lambda, 0),
+                     pearson = ifelse(Z, 1/sqrt(lambda), 0),
+                     score   = Z * X
+                     )
+
   continuous <- switch(type,
                        raw     = -lambda,
                        inverse = -indicator,
-                       pearson = -indicator * sqrt(lambda))
+                       pearson = -indicator * sqrt(lambda),
+                       score   = -lambda * X)
 
   # Discretised residual measure (return value)
   res <- discrete + W * continuous
 
   # name the residuals
   attr(res, "type") <- type
-  attr(res, "typename") <- paste(typetable[m], "residuals")
+  attr(res, "typename") <- paste(if(type == "pearson") "Pearson" else type,
+                                 "residuals")
 
   # also give the components of the exact residual measure
   attr(res, "discrete") <- discrete
